Changelog
=========


0.1.6 (2017-08-26)
------------------

Changes
~~~~~~~
- Using edit_miz for batch operations. [132nd-etcher]

Fix
~~~
- Remove CLRXXXX from metar string while parsing. [132nd-etcher]


0.1.5 (2017-08-26)
------------------

Fix
~~~
- Catch ParserError while parsing for metar string. [132nd-etcher]


0.1.4 (2017-08-24)
------------------
- Add mission time. [132nd-etcher]


0.1.3 (2017-08-20)
------------------
- Update changelog. [132nd-etcher]
- Pep8 formatting. [132nd-etcher]
- Remove unused module. [132nd-etcher]
- Move weather in package, add METAR builder and a few tests. [132nd-
  etcher]


0.1.2 (2017-08-20)
------------------
- Update changelog. [132nd-etcher]
- Update requirements. [132nd-etcher]
- Export _set_weather. [132nd-etcher]


0.1.1 (2017-08-19)
------------------
- Add MissionWeather to exports. [132nd-etcher]
- Dev: initial commit. [132nd-etcher]


0.1.0 (2017-08-19)
------------------
- Initial commit. [132nd-etcher]